.. currentmodule:: sardana.pool.poolbasechannel

:mod:`~sardana.pool.poolbasechannel`
======================================

.. automodule:: sardana.pool.poolbasechannel

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`PoolBaseChannel`

PoolBaseChannel
-------------------

.. inheritance-diagram:: PoolBaseChannel
    :parts: 1
    
.. autoclass:: PoolBaseChannel
    :show-inheritance:
    :members:
    :undoc-members: